pub fn get_entry(
pool: &[ConstantPoolEntry],
index: u16,
) -> Option<&ConstantPoolEntry>Expand description
Helper to get a constant pool entry by its logical index (1-based, accounting for Long/Double double-slot).
pub fn get_entry(
pool: &[ConstantPoolEntry],
index: u16,
) -> Option<&ConstantPoolEntry>Helper to get a constant pool entry by its logical index (1-based, accounting for Long/Double double-slot).