pub fn get_utf8(pool: &[ConstantPoolEntry], index: u16) -> Option<&str>Expand description
Helper to resolve a UTF8 string from the constant pool by index (1-based). Returns None if the index is out of bounds or not a UTF8 entry.
pub fn get_utf8(pool: &[ConstantPoolEntry], index: u16) -> Option<&str>Helper to resolve a UTF8 string from the constant pool by index (1-based). Returns None if the index is out of bounds or not a UTF8 entry.