pub fn parse_specialized_attribute(
attr: &AttributeInfo,
pool: &[ConstantPoolEntry],
) -> ParsedAttributeExpand description
Try to parse a raw attribute into a specialized attribute type based on the attribute name.
pub fn parse_specialized_attribute(
attr: &AttributeInfo,
pool: &[ConstantPoolEntry],
) -> ParsedAttributeTry to parse a raw attribute into a specialized attribute type based on the attribute name.